EnumFallbackConfig class

Constructors

EnumFallbackConfig({required bool generateFallbackValuesGlobally, String? globalEnumFallbackName, required Map<String, String> fallbackValueMap})
const

Properties

fallbackValueMap → Map<String, String>
final
generateFallbackValuesGlobally → bool
final
globalEnumFallbackName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited